::: nyckel.TabularClassificationFunction

::: nyckel.TabularClassificationSample

::: nyckel.TabularSampleData

::: nyckel.TabularFieldKey

::: nyckel.TabularFieldValue

::: nyckel.TabularFunctionField
